function GcTmGui
% GcTmGui
% GcTmGui defines the Grafical User Interface, GUI, interface look
% All GUI buttons call GcTmCmd
% Text fields and buttons are tagged with a 'tag'
% for identification
%
% 

screen=get(0,'screenSize');
figPos=[
         0.05 0.51 0.45 0.4;
         0.51 0.51 0.45 0.4;
         0.05 0.1 0.45 0.36;
         0.51 0.1 0.45 0.3
        ];

backGroundColor=[0.8 0.8 0.8];
close all
figure(3);
set(gcf,'pos',figPos(3,:).*[screen(3) screen(4) screen(3) screen(4)])
set(gcf,'name','Gaussian curve fit Analysis of Tm');
set(gcf,'MenuBar','none');
set(gcf,'color',backGroundColor);

fileName='';

%Find path to data directory
myPath=mfilename('fullpath');
n=find(myPath=='\',1,'last');
myDataPath=[myPath(1:n) 'data\'];

%Directory text+input
uicontrol('Style','text', ...
            'Units','normal', ...
            'Position',[0.05 0.9 0.4 0.1], ...
            'FontSize',12,...
            'Horizontal','left',...
            'String','Directory:',...
            'backGroundColor',backGroundColor);
        
 uicontrol('Style','edit', ...
            'Units','normal', ...
            'Position',[0.3 0.9 0.65 0.1], ...
            'String',myDataPath, ...
            'FontSize',8,...
            'Horizontal','left',...
            'backGroundColor',[1 1 1],...
            'Tag','directory', ...
            'ToolTips','', ...
            'callback','');

%File text+input
uicontrol('Style','text', ...
            'Units','normal', ...
            'Position',[0.05 0.8 0.4 0.1], ...
            'FontSize',12,...
            'Horizontal','left',...
            'String','File:',...
            'backGroundColor',backGroundColor)
uicontrol('Style','edit', ...
            'Units','normal', ...
            'Position',[0.3 0.8 0.65 0.1], ...
            'FontSize',8,...
            'String',fileName, ...
            'Horizontal','left',...
            'backGroundColor',[1 1 1],...
            'Tag','filename', ...
            'ToolTips','', ...
            'callback','');
%Limit
uicontrol('Style','text', ...
            'Units','normal', ...
            'Position',[0.05 0.7 0.4 0.1], ...
            'FontSize',12,...
            'Horizontal','left',...
            'String','Limit (std):',...
            'backGroundColor',backGroundColor)
uicontrol('Style','edit', ...
            'Units','normal', ...
            'Position',[0.3 0.7 0.1 0.1], ...
            'FontSize',10,...
            'String','1.2', ...
            'Horizontal','left',...
            'backGroundColor',[1 1 1],...
            'Tag','limit', ...
            'ToolTips','', ...
            'callback','');

        
%Status text+input
uicontrol('Style','text', ...
            'Units','normal', ...
            'Position',[0.05 0.55 0.4 0.1], ...
            'FontSize',12,...
            'Horizontal','left',...
            'String','Status:',...
            'backGroundColor',backGroundColor)
uicontrol('Style','edit', ...
            'Units','normal', ...
            'Position',[0.3 0.55 0.65 0.1], ...
            'FontSize',8,...
            'String','', ...
            'Horizontal','left',...
            'backGroundColor',[1 1 1],...
            'Tag','status', ...
            'ToolTips','', ...
            'callback','');
        
        
%Pushbutton File
uicontrol('Style','pushbutton', ...
            'Units','normal', ...
            'Position',[0.05 0.4 0.3 0.1], ...
            'FontSize',12,...
            'String','File', ...
            'Horizontal','center',...
            'ToolTips','', ...
            'callback','GcTmCmd(''file'')');
        
%Pushbutton Run
uicontrol('Style','pushbutton', ...
            'Units','normal', ...
            'Position',[0.05 0.3 0.3 0.1], ...
            'FontSize',12,...
            'String','Run', ...
            'tag','runbutton',...
            'Horizontal','center',...
            'ToolTips','', ...
            'callback','GcTmCmd(''run'')');
        
%Pushbutton Plot Mesh
uicontrol('Style','pushbutton', ...
            'Units','normal', ...
            'Position',[0.55 0.4 0.2 0.1], ...
            'FontSize',12,...
            'String','Plot Mesh', ...
            'tag','',...
            'Horizontal','center',...
            'ToolTips','', ...
            'callback','GcTmCmd(''plotmesh'')');
        
%Pushbutton Plot Well
uicontrol('Style','pushbutton', ...
            'Units','normal', ...
            'Position',[0.55 0.3 0.2 0.1], ...
            'FontSize',12,...
            'String','Plot well', ...
            'tag','',...
            'Horizontal','center',...
            'ToolTips','', ...
            'callback','GcTmCmd(''plotwell'')');

uicontrol('Style','pushbutton', ...
            'Units','normal', ...
            'Position',[0.55-0.1 0.3 0.1 0.1], ...
            'FontSize',12,...
            'String','<', ...
            'tag','',...
            'Horizontal','center',...
            'ToolTips','', ...
            'callback','GcTmCmd(''plotwell<'')');
        
uicontrol('Style','pushbutton', ...
            'Units','normal', ...
            'Position',[0.55+0.2 0.3 0.1 0.1], ...
            'FontSize',12,...
            'String','>', ...
            'tag','',...
            'Horizontal','center',...
            'ToolTips','', ...
            'callback','GcTmCmd(''plotwell>'')');
        
uicontrol('Style','edit', ...
            'Units','normal', ...
            'Position',[0.55 0.2 0.2 0.1], ...
            'FontSize',12,...
            'String','1', ...
            'tag','wellnr',...
            'Horizontal','center',...
            'ToolTips','');

        
        
%Pushbutton Run All
uicontrol('Style','pushbutton', ...
            'Units','normal', ...
            'Position',[0.05 0.2 0.3 0.1], ...
            'FontSize',12,...
            'String','Run All', ...
            'Horizontal','center',...
            'ToolTips','', ...
            'callback','GcTmCmd(''runall'')');
        
        
%Pushbutton End
uicontrol('Style','pushbutton', ...
            'Units','normal', ...
            'Position',[0.05 0.1 0.3 0.1], ...
            'FontSize',12,...
            'String','End', ...
            'Horizontal','center',...
            'ToolTips','', ...
            'callback','GcTmCmd(''end'')');

% text by ....        
uicontrol('Style','text', ...
            'Units','normal', ...
            'Position',[0.1 0 0.8 0.1], ...
            'FontSize',8,...
            'String','by Christoffer Nellker', ...
            'Horizontal','center',...
            'backGroundColor',backGroundColor);

